.pybi-flow-box>.echart-box>.echart[data-v-acc7a2a2]{min-width:30vw}.echart-box[data-v-acc7a2a2]{position:relative;width:100%;height:100%}.echart-box .echart[data-v-acc7a2a2]{width:100%;height:var(--91538b48)}.echart-box .echart.min-height-chart[data-v-acc7a2a2]{min-height:30vh}.echart-box .debug-box[data-v-acc7a2a2]{z-index:9999;position:absolute;top:0;left:0;transform:translateY(-100%);display:flex;max-width:100%}.echart-box .back[data-v-acc7a2a2]{z-index:9999;display:inline-block;border:1px solid #000;border-radius:12%;padding:.2em}.echart-box .back[data-v-acc7a2a2]:hover{cursor:pointer}
