.mermaid-box[data-v-d56297d5]{width:100%;position:relative;display:flex;flex-direction:column;gap:0}.mermaid-box:hover .back-to[data-has-pre=true][data-v-d56297d5]{z-index:999;opacity:1}.back-to[data-v-d56297d5]{--label-main-color: rgba(88, 140, 195, .9);z-index:-999;border:1px solid var(--label-main-color);border-radius:15px;width:4em;height:3em;padding:1em .5em;display:flex;gap:.3em;justify-content:center;align-items:center;opacity:0;user-select:none;cursor:pointer;height:1.5em;transition:.3s}.back-to[data-v-d56297d5]:hover{text-decoration:underline}
